==> haskell-servant-server-0.19.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 servant-server
version:              0.19.2
visibility:           public
id:                   servant-server-0.19.2-5pb18vutHQg9KOupyhEmIH
key:                  servant-server-0.19.2-5pb18vutHQg9KOupyhEmIH
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:
    A family of combinators for defining webservices APIs and serving them

description:
    A family of combinators for defining webservices APIs and serving them

    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.

    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.

    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  f9c869a65a45f9746a5e3e8a6d94a056
exposed:              True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Generic Servant.Server.Internal
    Servant.Server.Internal.BasicAuth Servant.Server.Internal.Context
    Servant.Server.Internal.Delayed Servant.Server.Internal.DelayedIO
    Servant.Server.Internal.ErrorFormatter
    Servant.Server.Internal.Handler Servant.Server.Internal.RouteResult
    Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServerError Servant.Server.StaticFiles
    Servant.Server.UVerb Servant.Utils.StaticFiles

import-dirs:          /usr/lib/ghc-9.0.2/site-local/servant-server-0.19.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/servant-server-0.19.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-server
hs-libraries:         HSservant-server-0.19.2-5pb18vutHQg9KOupyhEmIH
depends:
    base-4.15.1.0 base-compat-0.12.2-l1EqrM7Qwu6Pq9d4drKFu
    base64-bytestring-1.2.1.0-iG6YBGhLkRJagBsFqRAI2
    bytestring-0.10.12.1 constraints-0.13.4-EP04dodd4em2GV3r2raZRS
    containers-0.6.4.1 exceptions-0.10.4 filepath-1.4.2.1
    http-api-data-0.5-CU7OIrowpy57QE8onWhyzh
    http-media-0.8.0.0-HXwSdb5ej131khAvPb77zv
    http-types-0.12.3-L4VBkj9wBbpJhmiMCXrA05
    monad-control-1.0.3.1-21gUZpZbgH5KO3QvMCPaGC mtl-2.2.2
    network-3.1.2.7-2x6X3kWddA03AmOITnySLy
    network-uri-2.6.4.1-CJy9K6CUGBYDMBcoIm8TMq
    resourcet-1.2.6-3amKdWDZReE3TYUO4zdEYT
    servant-0.19.1-HFHLYn5uUzmHTmiTLf0Pzm
    sop-core-0.5.0.2-3jnDWqiXqcyAzV81XsfWbk
    string-conversions-0.4.0.1-8ZoYq0HVxDcHsacv3tIOmh
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR text-1.2.5.0
    transformers-0.5.6.2 transformers-base-0.4.6-2M49J28Ed0L2XQvH4AySxP
    wai-3.2.3-4BBvzsOByYiKnH9wzG1k6K
    wai-app-static-3.1.7.4-5Oef35KtksQ5k3vwlfwbVK
    word8-0.1.3-AazxEC5xyKiELvx3OUlEW

haddock-interfaces:
    /usr/share/doc/haskell-servant-server/html/servant-server.haddock

haddock-html:         /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-server-0.19.2-81-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 servant-server
version:              0.19.2
visibility:           public
id:                   servant-server-0.19.2-F4rz22QYOXl9DqJAfxLRth
key:                  servant-server-0.19.2-F4rz22QYOXl9DqJAfxLRth
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:
    A family of combinators for defining webservices APIs and serving them

description:
    A family of combinators for defining webservices APIs and serving them

    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.

    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.

    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  c52cfbc87f158011a754fc35638e971e
exposed:              True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Generic Servant.Server.Internal
    Servant.Server.Internal.BasicAuth Servant.Server.Internal.Context
    Servant.Server.Internal.Delayed Servant.Server.Internal.DelayedIO
    Servant.Server.Internal.ErrorFormatter
    Servant.Server.Internal.Handler Servant.Server.Internal.RouteResult
    Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServerError Servant.Server.StaticFiles
    Servant.Server.UVerb Servant.Utils.StaticFiles

import-dirs:          /usr/lib/ghc-9.0.2/site-local/servant-server-0.19.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/servant-server-0.19.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-server
hs-libraries:         HSservant-server-0.19.2-F4rz22QYOXl9DqJAfxLRth
depends:
    base-4.15.1.0 base-compat-0.12.2-l1EqrM7Qwu6Pq9d4drKFu
    base64-bytestring-1.2.1.0-D7qbdpqh7ZAHvyipCqb2En
    bytestring-0.10.12.1 constraints-0.13.4-Hw1XRw7WPulJgyFCCNHZXH
    containers-0.6.4.1 exceptions-0.10.4 filepath-1.4.2.1
    http-api-data-0.5.1-GaKGEnCo0PR6YcJFBpYdl0
    http-media-0.8.1.0-DjOMt8xv1TyDtAERH5LZ2T
    http-types-0.12.3-GFhxs6XVQ6bETbOR4vEFmW
    monad-control-1.0.3.1-35h1aVdsL57202S8tnbNU9 mtl-2.2.2
    network-3.1.4.0-5PP4MrJJnZZJkybIlRRAPq
    network-uri-2.6.4.2-18lVeOrHqdkDTTcK9hqBly
    resourcet-1.2.6-AavQnD5kc82Iq3gAOb9Jer
    servant-0.19.1-3K8ExXu36yw6Qw9Vmu05LI
    sop-core-0.5.0.2-3jnDWqiXqcyAzV81XsfWbk
    string-conversions-0.4.0.1-Hd9pizHKYvT77j3eZuOf8y
    tagged-0.8.7-8MQxDldL1qw9fJF5LZxnpf text-1.2.5.0
    transformers-0.5.6.2 transformers-base-0.4.6-92OnlKVmSzm7Q6K6Tg9Pzs
    wai-3.2.3-BDPWmqf0MooISXwouhUuyf
    wai-app-static-3.1.8-IDqHKCCkvQ7I6UtY2pZvGW
    word8-0.1.3-AazxEC5xyKiELvx3OUlEW

haddock-interfaces:
    /usr/share/doc/haskell-servant-server/html/servant-server.haddock

haddock-html:         /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
